@@ -1,6 +1,7 @@
 from pathlib import Path
-from typing import List, Union
+from typing import List, Type, Union
 
+from .connection.abstract_connection import AbstractConnection
 from .connection.lircd_connection import LircdConnection
 from .exceptions import LircdCommandFailureError
 from .reply_packet_parser import ReplyPacketParser
@@ -9,7 +10,7 @@ from .reply_packet_parser import ReplyPacketParser
 class Client:
     """Communicate with the lircd daemon."""
 
-    def __init__(self, connection: LircdConnection = None) -> None:
+    def __init__(self, connection: Type[AbstractConnection] = None) -> None:
         """
         Initialize the client by connecting to the lircd socket.
 
@@ -18,23 +19,23 @@ class Client:
             depending on the operating system if one is not provided.
 
         Raises:
-            TypeError: If connection is not an instance of LircdConnection.
+            TypeError: If connection is not an instance of AbstractConnection.
             LircdConnectionError: If the socket cannot connect to the address.
         """
         if not connection:
             connection = LircdConnection()
 
-        if not isinstance(connection, LircdConnection):
-            raise TypeError("`connection` must be an instance of `LircdConnection`")
+        if not isinstance(connection, AbstractConnection):
+            raise TypeError("`connection` must be an instance of `AbstractConnection`")
 
         # Used for start_repeat and stop_repeat
-        self.__last_send_start_remote = None
-        self.__last_send_start_key = None
+        self._last_send_start_remote = None
+        self._last_send_start_key = None
 
-        self.__connection = connection
-        self.__connection.connect()
+        self._connection = connection
+        self._connection.connect()
 
-    def __send_command(self, command: str) -> Union[str, List[str]]:
+    def _send_command(self, command: str) -> Union[str, List[str]]:
         """
         Send a command to lircd.
 
@@ -44,11 +45,11 @@ class Client:
         Returns:
             The data from the lirc response packet.
         """
-        self.__connection.send(command)
+        self._connection.send(command)
 
         parser = ReplyPacketParser()
         while not parser.is_finished:
-            line = self.__connection.readline()
+            line = self._connection.readline()
             parser.feed(line)
 
         parser_data = parser.data[0] if len(parser.data) == 1 else parser.data
@@ -62,7 +63,7 @@ class Client:
 
     def close(self) -> None:
         """Close the connection to the socket."""
-        self.__connection.close()
+        self._connection.close()
 
     def send_once(self, remote: str, key: str, repeat_count: int = 0) -> None:
         """
@@ -84,7 +85,7 @@ class Client:
         Raises:
             LircdCommandFailure: If the command fails.
         """
-        self.__send_command(f"SEND_ONCE {remote} {key} {repeat_count}")
+        self._send_command(f"SEND_ONCE {remote} {key} {repeat_count}")
 
     def send_start(self, remote: str, key: str) -> None:
         """
@@ -100,9 +101,9 @@ class Client:
         Raises:
             LircdCommandFailure: If the command fails.
         """
-        self.__last_send_start_remote = remote
-        self.__last_send_start_key = key
-        self.__send_command(f"SEND_START {remote} {key}")
+        self._last_send_start_remote = remote
+        self._last_send_start_key = key
+        self._send_command(f"SEND_START {remote} {key}")
 
     def send_stop(self, remote: str = "", key: str = "") -> None:
         """
@@ -120,13 +121,13 @@ class Client:
         Raises:
             LircdCommandFailure: If the command fails.
         """
-        if not remote and self.__last_send_start_remote:
-            remote = self.__last_send_start_remote
+        if not remote and self._last_send_start_remote:
+            remote = self._last_send_start_remote
 
-        if not key and self.__last_send_start_key:
-            key = self.__last_send_start_key
+        if not key and self._last_send_start_key:
+            key = self._last_send_start_key
 
-        self.__send_command(f"SEND_STOP {remote} {key}")
+        self._send_command(f"SEND_STOP {remote} {key}")
 
     def list_remotes(self) -> List[str]:
         """
@@ -139,7 +140,7 @@ class Client:
         Returns:
             The list of all remotes.
         """
-        return self.__send_command("LIST")
+        return self._send_command("LIST")
 
     def list_remote_keys(self, remote: str) -> List[str]:
         """
@@ -154,7 +155,7 @@ class Client:
         Returns:
             The list of keys from the remote.
         """
-        return self.__send_command(f"LIST {remote}")
+        return self._send_command(f"LIST {remote}")
 
     def start_logging(self, path: Union[str, Path]) -> None:
         """
@@ -167,7 +168,7 @@ class Client:
         Raises:
             LircdCommandFailure: If the command fails.
         """
-        self.__send_command(f"SET_INPUTLOG {path}")
+        self._send_command(f"SET_INPUTLOG {path}")
 
     def stop_logging(self) -> None:
         """
@@ -178,7 +179,7 @@ class Client:
         """
         # When calling SET_INPUTLOG without the path argument,
         # it will stop logging and close the logfile.
-        self.__send_command("SET_INPUTLOG")
+        self._send_command("SET_INPUTLOG")
 
     def version(self) -> str:
         """
@@ -190,7 +191,7 @@ class Client:
         Returns:
             The version of LIRC being used.
         """
-        return self.__send_command("VERSION")
+        return self._send_command("VERSION")
 
     def driver_option(self, key: str, value: str) -> None:
         """
@@ -203,7 +204,7 @@ class Client:
         Raises:
             LircdCommandFailure: If the command fails.
         """
-        self.__send_command(f"DRV_OPTION {key} {value}")
+        self._send_command(f"DRV_OPTION {key} {value}")
 
     def simulate(
         self, remote: str, key: str, repeat_count: int = 1, keycode: int = 0
@@ -231,7 +232,7 @@ class Client:
         Raises:
             LircdCommandFailure: If the command fails.
         """
-        self.__send_command(
+        self._send_command(
             "SIMULATE %016d %02d %s %s\n" % (keycode, repeat_count, key, remote)
         )
 
@@ -261,4 +262,4 @@ class Client:
             for transmitter in transmitters:
                 mask |= 1 << (int(transmitter) - 1)
 
-        self.__send_command(f"SET_TRANSMITTERS {mask}")
+        self._send_command(f"SET_TRANSMITTERS {mask}")
