@@ -11,7 +11,7 @@ class DefaultConnection:
         This class provides our operating specific default
         connection parameters.
         """
-        self.__operating_system = platform.system()
+        self._operating_system = platform.system()
 
     @property
     def socket(self) -> socket.socket:
@@ -26,14 +26,14 @@ class DefaultConnection:
             UnsupportedOperatingSystemError: If the OS is not Linux, Windows,
             or Darwin.
         """
-        if self.__operating_system == "Linux" or self.__operating_system == "Darwin":
+        if self._operating_system == "Linux" or self._operating_system == "Darwin":
             return socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
 
-        if self.__operating_system == "Windows":
+        if self._operating_system == "Windows":
             return socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
         raise UnsupportedOperatingSystemError(
-            f"{self.__operating_system} is not supported for a default OS "
+            f"{self._operating_system} is not supported for a default OS "
             "socket to lircd."
         )
 
@@ -57,9 +57,9 @@ class DefaultConnection:
                 "Linux": "/var/run/lirc/lircd",
                 "Windows": ("localhost", 8765),
                 "Darwin": "/opt/local/var/run/lirc/lircd",
-            }[self.__operating_system]
+            }[self._operating_system]
         except KeyError:
             raise UnsupportedOperatingSystemError(
-                f"{self.__operating_system} is not supported for a default OS "
+                f"{self._operating_system} is not supported for a default OS "
                 "address to lircd."
             )
